@@ -5,5 +5,5 @@ fn main(){
     let seed = phrase.derive_seed("Password1234", Language::English);
 
     let keypair = SchnorrKeypair::new(&seed.as_bytes());
-    let signature = keypair.simple_sign(b"This is the Context",b"This message is being signed");
+    let signature = keypair.sign(b"This is the Context",b"This message is being signed");
 }
\ No newline at end of file
